/*
  libuta - a C++ widget library based on SDL (Simple Direct Layer)
  Copyright (C) 1999-2002  Karsten Laux

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.
  
  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.
  
  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the
  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA  02111-1307, SA.
*/

#ifndef _MESSAGEBOX_H
#define _MESSAGEBOX_H

#include "dialogbox.h"

namespace uta {

///
class MessageBox : public uDialogBox
{
 
 public:
  ///
  MessageBox(const std::string& title, const std::string& msg);
  ///
  MessageBox(const std::string& msg);
  ///
  virtual ~MessageBox();


};


}

#endif // !_MESSAGEBOX
